METHODS = [
    'test', 'key_get', 'key_set', 'key_list', 'key_list_all',
    'key_get_recursive', 'key_copy', 'key_rename', 'key_exists', 'key_explain',
    'key_delete', 'key_delete_recursive', 'purge', 'check', 'repair', 'info',
    'key_dump', 'key_load', 'key_update', 'safe_purge', 'purge_cache',
    'server_set', 'key_increment', 'key_decrement', 'key_get_field',
    'key_set_field', 'key_delete_field'
]

DEFAULT_SERVER_PORT = 8870



__version__ = '0.2.18'

import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='yedb',
    version=__version__,
    author='Altertech',
    author_email='pr@altertech.com',
    description='Rugged embedded and client/server key/value database',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/alttch/yedb',
    packages=setuptools.find_packages(),
    include_package_data=True,
    license='Apache License 2.0',
    install_requires=['portalocker', 'cachetools', 'jsonschema', 'msgpack'],
    extras_require={
        'cli': [
            'icli', 'neotermcolor', 'rapidtables', 'pyyaml', 'tqdm', 'pygments',
            'getch'
        ]
    },
    classifiers=(
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Apache Software License',
        'Topic :: Database',
        'Topic :: Database :: Database Engines/Servers',
    ),
    scripts=['bin/yedb'])
